@@ -47,9 +47,6 @@ class PubNub(PubNubCore):
         self._request_handler = handler
 
     def request_sync(self, endpoint_call_options):
-        if endpoint_call_options.method_string == "POST":
-            self.headers['Content-type'] = "application/json"
-
         platform_options = PlatformOptions(self.headers, self.config)
 
         self.merge_in_params(endpoint_call_options)
@@ -60,9 +57,6 @@ class PubNub(PubNubCore):
         return self._request_handler.sync_request(platform_options, endpoint_call_options)
 
     def request_async(self, endpoint_name, endpoint_call_options, callback, cancellation_event):
-        if endpoint_call_options.method_string == "POST":
-            self.headers['Content-type'] = "application/json"
-
         platform_options = PlatformOptions(self.headers, self.config)
 
         self.merge_in_params(endpoint_call_options)
@@ -70,8 +64,13 @@ class PubNub(PubNubCore):
         if self.config.log_verbosity:
             print(endpoint_call_options)
 
-        return self._request_handler.async_request(endpoint_name, platform_options, endpoint_call_options,
-                                                   callback, cancellation_event)
+        return self._request_handler.async_request(
+            endpoint_name,
+            platform_options,
+            endpoint_call_options,
+            callback,
+            cancellation_event
+        )
 
     def merge_in_params(self, options):
 
