@@ -6,11 +6,15 @@ from .enums import PNStatusCategory, PNOperationType
 from .models.consumer.common import PNStatus
 from .models.consumer.pn_error_data import PNErrorData
 from .utils import strip_right
-from .models.consumer.pubsub import PNPresenceEventResult, PNMessageResult, PNSignalMessageResult, PNMessageActionResult
+from .models.consumer.pubsub import (
+    PNPresenceEventResult, PNMessageResult, PNSignalMessageResult, PNMessageActionResult, PNFileMessageResult
+)
 from .models.server.subscribe import SubscribeMessage, PresenceEnvelope
 from .models.consumer.user import PNUserResult
 from .models.consumer.space import PNSpaceResult
 from .models.consumer.membership import PNMembershipResult
+from .endpoints.file_operations.get_file_url import GetFileDownloadUrl
+
 
 logger = logging.getLogger("pubnub")
 
@@ -20,6 +24,7 @@ class SubscribeMessageWorker(object):
     TYPE_SIGNAL = 1
     TYPE_OBJECT = 2
     TYPE_MESSAGE_ACTION = 3
+    TYPE_FILE_MESSAGE = 4
 
     def __init__(self, pubnub_instance, listener_manager_instance, queue_instance, event):
         # assert isinstance(pubnub_instnace, PubNubCore)
@@ -39,12 +44,21 @@ class SubscribeMessageWorker(object):
     def _take_message(self):
         pass
 
+    def _get_url_for_file_event_message(self, channel, extracted_message):
+        return GetFileDownloadUrl(self._pubnub)\
+            .channel(channel) \
+            .file_name(extracted_message["file"]["name"])\
+            .file_id(extracted_message["file"]["id"]).get_complete_url()
+
     def _process_message(self, message_input):
         if self._pubnub.config.cipher_key is None:
             return message_input
         else:
             try:
-                return self._pubnub.config.crypto.decrypt(self._pubnub.config.cipher_key, message_input)
+                return self._pubnub.config.crypto.decrypt(
+                    self._pubnub.config.cipher_key,
+                    message_input
+                )
             except Exception as exception:
                 logger.warning("could not decrypt message: \"%s\", due to error %s" % (message_input, str(exception)))
                 pn_status = PNStatus()
@@ -110,6 +124,24 @@ class SubscribeMessageWorker(object):
                     data=message.payload['data']
                 )
                 self._listener_manager.announce_membership(membership_result)
+
+        elif message.type == SubscribeMessageWorker.TYPE_FILE_MESSAGE:
+            extracted_message = self._process_message(message.payload)
+            download_url = self._get_url_for_file_event_message(channel, extracted_message)
+
+            pn_file_result = PNFileMessageResult(
+                message=extracted_message.get("message"),
+                channel=channel,
+                subscription=subscription_match,
+                timetoken=publish_meta_data.publish_timetoken,
+                publisher=message.issuing_client_id,
+                file_url=download_url,
+                file_id=extracted_message["file"]["id"],
+                file_name=extracted_message["file"]["name"]
+            )
+
+            self._listener_manager.announce_file_message(pn_file_result)
+
         else:
             extracted_message = self._process_message(message.payload)
             publisher = message.issuing_client_id
@@ -126,6 +158,7 @@ class SubscribeMessageWorker(object):
                     publisher=publisher
                 )
                 self._listener_manager.announce_signal(pn_signal_result)
+
             elif message.type == SubscribeMessageWorker.TYPE_MESSAGE_ACTION:
                 message_action = extracted_message['data']
                 if 'uuid' not in message_action:
@@ -133,6 +166,7 @@ class SubscribeMessageWorker(object):
 
                 message_action_result = PNMessageActionResult(message_action)
                 self._listener_manager.announce_message_action(message_action_result)
+
             else:
                 pn_message_result = PNMessageResult(
                     message=extracted_message,
